Learn R Programming

meltt (version 0.4.3)

crash_taxonomies: Taxonomies to illustrate the functionality of meltt

Description

These taxonomies formalize how the information about model, color, and type of accident in our three artificial car crash datasets map onto one another.

Usage

data(crashMD)

Arguments

Format

A list of three data.frame containing information about the different categories (specific to general) of models, colors and degree of damages coded in each dataset.

Author

Karsten Donnay and Eric Dunford.

References

Karsten Donnay, Eric T. Dunford, Erin C. McGrath, David Backer, David E. Cunningham. (2018). "Integrating Conflict Event Data." Journal of Conflict Resolution.