Auxiliary function used within meltt to index events as multiple datasets are processed.
meltt.disambiguate(data, match_output, indexing, priormatches, averaging)meltt.disambiguate returns a list containing two object: a data frame with all located matches paired and a new index, specifying the data frame as a single frame, and a running index of all matched events.
data to be disambiguated passed as data.frame object from meltt. See details.
data.frame object of identified matches passed from meltt.match. See details.
data.frame object passed from meltt that specifies the correct index for every event and dataset. See details.
prior matches (if any) passed as data.frame. See details.
specification if common information among matches should be averaged. Passed from meltt. See details.
Karsten Donnay and Eric Dunford.
Auxilary function used within meltt to index events as multiple datasets are processed. Function keeps track of matching and non-matching events as each subsequent data.frame is processed. Using the identified matches from the meltt.match output, meltt.disambiguate merges the matches in the data and indexes the match. indexing is used for correct labeling of matches in case more than two datasets are merged. averaging averages the common information between matching events. The parameter is specified within the main function meltt.
Karsten Donnay, Eric T. Dunford, Erin C. McGrath, David Backer, David E. Cunningham. (2018). "Integrating Conflict Event Data." Journal of Conflict Resolution.
meltt