Learn R Programming

meltt (version 0.4.3)

meltt.taxonomy: Handling of taxonomy inputs [Auxiliary Function].

Description

Auxiliary function that maps secondary taxonomies onto the input data and transforms the taxonomies into a numerical matrices.

Usage

meltt.taxonomy(data, taxonomies)

Value

Returns a numerical matrix that contains all data indices, date/enddate, longitude/latitude, and taxonomies.

Arguments

data

object of class data.frame.

taxonomies

object of class list, containing data.frames of input taxonomies for secondary matching criteria.

Author

Karsten Donnay and Eric Dunford.

Details

meltt.taxonomy maps the user-created taxonomies onto the input data, and converts the taxonomy to a numerical matrix. The taxonomies are used as secondary criteria in the matching procedure.

References

Karsten Donnay, Eric T. Dunford, Erin C. McGrath, David Backer, David E. Cunningham. (2018). "Integrating Conflict Event Data." Journal of Conflict Resolution.

See Also

meltt