Auxiliary function that maps secondary taxonomies onto the input data and transforms the taxonomies into a numerical matrices.
meltt.taxonomy(data, taxonomies)Returns a numerical matrix that contains all data indices, date/enddate, longitude/latitude, and taxonomies.
object of class data.frame.
object of class list, containing data.frames of input taxonomies for secondary matching criteria.
Karsten Donnay and Eric Dunford.
meltt.taxonomy maps the user-created taxonomies onto the input data, and converts the taxonomy to a numerical matrix. The taxonomies are used as secondary criteria in the matching procedure.
Karsten Donnay, Eric T. Dunford, Erin C. McGrath, David Backer, David E. Cunningham. (2018). "Integrating Conflict Event Data." Journal of Conflict Resolution.
meltt